==> 2.2.4.zip: c/config/config.js <==
var config = {
  // url: "http://10.11.205.51:7000/C/api",
  // url: "https://ciformall.youlane.cn/C/api",
  url:"https://c.malls.iformall.com/C/api",
  // url: "http://31adc9ce.ngrok.io/C/api",
  api: {
    /**
     * 接口用途:login
     */
    login: "/user/login",
    /**
     * 授权后获取用户的昵称,unionId等信息
     */
    getUserInfo: "/user/getUserInfo",
    /**
     * 接口用途:授权后获取用户的手机号
     */
    getUserPhone: "/user/getUserPhone",
    /**
     * 检查用户授权状态
     */
    checkUserStatus: "/user/checkUserStatus",
    /**
     * 检查用户手机授权状态
     */
    checkPhoneStatus: "/user/checkPhoneStatus",
    /**
     * 优惠券详情
     */
    couponDetail: "/wxCoupon/detail",

    /**
     * 业态查询
     */
    businessList: "/wxBusiness/list",
    /**
     * 频道查询
     */
    couponChannelList: "/wxCouponChannel/list",
    /**
     * 下订单
     */
    orderSave: "/order/save",
    /**
     * 支付订单
     */
    payOrderCreate: "/pay/create",
    /**
     * 订单状态更新
     */
    payOrderUpdate: "/pay/updatePayOrder",
    /**
     * 订单列表
     */
    orderList: "/order/list",

    /**
     *  订单详情
     */
    orderDetail: "/order/detail",
    /**
     * 券包
     */
    couponOrderList: "/couponOrder/list",
    /**
     * 券包详情
     */
    couponOrderDetail: "/couponOrder/detail", /// TODO
    /**
     * 验证码发送
     */
    sendValidationCode: "/wxMsgValidationcode/sendvalidationcode",
    /**
     * 验证码确认
     */
    validationCode: "/wxMsgValidationcode/hasvalidationcode",
    /**
     * 车场信息获取
     */
    getParkInfo: "/wxPark/info",
    /**
     * 用户所绑车牌获取
     */
    userCarCount: "/user/carCount",
    /**
     * 用户所绑车牌获取
     */
    getUserCarList: "/user/carList",
    /**
     * 联合登录
     */
    carInit: "/car/init",
    /**
     * 绑车牌
     */
    bindCar: "/car/bindCar",
    /**
     * 解绑车牌
     */
    unbindCar: "/car/unbindCar",
    /**
     * 停车费
     */
    getCarStopFee: "/car/getCarStopFee",
    /**
     * 停车费抵扣 （TJD）
     */
    deductionFee: "/car/deductionFee",
    /**
     * 优免券领取
     */
    getCarCoupon: "/car/getCoupon",
    /**
     * 停车券包
     */
    couponOrderCarList: "/car/couponOrderList",
    /**
     * banner
     */
    bannerlist: "/wxCampaign/list",
    /**
     * banner详情页面
     */
    bannerDetail: "/wxCampaign/findById",
    /**
     *  授权个人信息
     * 和授权手机号
     * 和login页面
     * 页面的图标
     */
    marketicon: '/mall/getAppIcon',
    /**
     * 获取停车场状态
     */
    getParkStatus: '/car/getParkStatus',
    /**
     * 检查核销的状态
     */
    getStatus: "/couponOrder/getStatus",
    /**
     * 获得成长值
     */
    getScore: '/user/userinfo',
    /**
     * 小程序分享
     * title
     * 描述
     */
    getWeapNote: '/mall/getWeapNote',
    scoreLevelInfo: '/mall/scoreLevelInfo',
    getWeRunData: '/user/getWeRunData',
    /**
     * 小程序获取游戏路径
     */
    getGame:'/game/getOne',
    /**
     * 用户更新信息
     */
    updateInfo:"/user/updateUserInfo"

  },

  weapp: {
    AppId: "wx026ee7f6290aa336"
  },
  ErrorCode: {
    NICK_NOT_AUTH: 11004,
    PHONE_NOT_AUTH: 11005,
    PHONE_IS_ENCRYPTED: 11006
  }
};
/*
for (var key in config.api) {
   config.api[key] = apiPrefix + config.api[key];
}
*/
module.exports = config;

==> 2.2.5.zip: c/config/config.js <==
var config = {
  // url: "http://10.11.205.51:7000/C/api",
  url: "https://ciformall.youlane.cn/C/api",
  // url:"https://c.malls.iformall.com/C/api",
  // url: "http://31adc9ce.ngrok.io/C/api",
  api: {
    /**
     * 接口用途:login
     */
    login: "/user/login",
    /**
     * 授权后获取用户的昵称,unionId等信息
     */
    getUserInfo: "/user/getUserInfo",
    /**
     * 接口用途:授权后获取用户的手机号
     */
    getUserPhone: "/user/getUserPhone",
    /**
     * 检查用户授权状态
     */
    checkUserStatus: "/user/checkUserStatus",
    /**
     * 检查用户手机授权状态
     */
    checkPhoneStatus: "/user/checkPhoneStatus",
    /**
     * 优惠券详情
     */
    couponDetail: "/wxCoupon/detail",

    /**
     * 业态查询
     */
    businessList: "/wxBusiness/list",
    /**
     * 频道查询
     */
    couponChannelList: "/wxCouponChannel/list",
    /**
     * 下订单
     */
    orderSave: "/order/save",
    /**
     * 支付订单
     */
    payOrderCreate: "/pay/create",
    /**
     * 订单状态更新
     */
    payOrderUpdate: "/pay/updatePayOrder",
    /**
     * 订单列表
     */
    orderList: "/order/list",

    /**
     *  订单详情
     */
    orderDetail: "/order/detail",
    /**
     * 券包
     */
    couponOrderList: "/couponOrder/list",
    /**
     * 券包详情
     */
    couponOrderDetail: "/couponOrder/detail", /// TODO
    /**
     * 验证码发送
     */
    sendValidationCode: "/wxMsgValidationcode/sendvalidationcode",
    /**
     * 验证码确认
     */
    validationCode: "/wxMsgValidationcode/hasvalidationcode",
    /**
     * 车场信息获取
     */
    getParkInfo: "/wxPark/info",
    /**
     * 用户所绑车牌获取
     */
    userCarCount: "/user/carCount",
    /**
     * 用户所绑车牌获取
     */
    getUserCarList: "/user/carList",
    /**
     * 联合登录
     */
    carInit: "/car/init",
    /**
     * 绑车牌
     */
    bindCar: "/car/bindCar",
    /**
     * 解绑车牌
     */
    unbindCar: "/car/unbindCar",
    /**
     * 停车费
     */
    getCarStopFee: "/car/getCarStopFee",
    /**
     * 停车费抵扣 （TJD）
     */
    deductionFee: "/car/deductionFee",
    /**
     * 优免券领取
     */
    getCarCoupon: "/car/getCoupon",
    /**
     * 停车券包
     */
    couponOrderCarList: "/car/couponOrderList",
    /**
     * banner
     */
    bannerlist: "/wxCampaign/list",
    /**
     * banner详情页面
     */
    bannerDetail: "/wxCampaign/findById",
    /**
     *  授权个人信息
     * 和授权手机号
     * 和login页面
     * 页面的图标
     */
    marketicon: '/mall/getAppIcon',
    /**
     * 获取停车场状态
     */
    getParkStatus: '/car/getParkStatus',
    /**
     * 检查核销的状态
     */
    getStatus: "/couponOrder/getStatus",
    /**
     * 获得成长值
     */
    getScore: '/user/userinfo',
    /**
     * 小程序分享
     * title
     * 描述
     */
    getWeapNote:'/mall/getWeapNote',
    /**
     * 小程序获取游戏路径
     */
    getGame:'/game/getOne'
  },

  weapp: {
    AppId: "wxea71200db93d756b"
  },
  ErrorCode: {
    NICK_NOT_AUTH: 11004,
    PHONE_NOT_AUTH: 11005,
    PHONE_IS_ENCRYPTED: 11006
  }
};
/*
for (var key in config.api) {
   config.api[key] = apiPrefix + config.api[key];
}
*/
module.exports = config;
